/*
 * Wire
 * Copyright (C) 2024 Wire Swiss GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
 */

package com.wire.android.ui.home.gallery

import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.SnackbarHostState
import androidx.compose.runtime.Composable
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import com.wire.android.ui.common.bottomsheet.WireModalSheetState
import com.wire.android.ui.common.bottomsheet.rememberWireModalSheetState
import com.wire.android.ui.common.snackbar.LocalSnackbarHostState
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.launch

data class MediaGalleryScreenState(
    val snackbarHostState: SnackbarHostState,
    val modalBottomSheetState: WireModalSheetState,
    val coroutineScope: CoroutineScope
) {
    fun showContextualMenu(show: Boolean) {
        coroutineScope.launch {
            if (show) modalBottomSheetState.show()
            else modalBottomSheetState.hide()
        }
    }
}

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun rememberMediaGalleryScreenState(
    bottomSheetState: WireModalSheetState = rememberWireModalSheetState(),
    coroutineScope: CoroutineScope = rememberCoroutineScope()
): MediaGalleryScreenState {
    val snackbarHostState = LocalSnackbarHostState.current

    return remember {
        MediaGalleryScreenState(
            snackbarHostState = snackbarHostState,
            modalBottomSheetState = bottomSheetState,
            coroutineScope
        )
    }
}
